@@ -20,6 +20,7 @@ const (
 	DialectTiDB       Dialect = database.DialectTiDB
 	DialectVertica    Dialect = database.DialectVertica
 	DialectYdB        Dialect = database.DialectYdB
+	DialectDuckDB     Dialect = database.DialectDuckDB
 )
 
 func init() {
@@ -50,6 +51,10 @@ func SetDialect(s string) error {
 		d = dialect.Vertica
 	case "ydb":
 		d = dialect.Ydb
+	case "turso":
+		d = dialect.Turso
+	case "duckdb":
+		d = dialect.Duckdb
 	default:
 		return fmt.Errorf("%q: unknown dialect", s)
 	}
