@@ -13,4 +13,6 @@ const (
 	Clickhouse Dialect = "clickhouse"
 	Vertica    Dialect = "vertica"
 	Ydb        Dialect = "ydb"
+	Turso      Dialect = "turso"
+	Duckdb     Dialect = "duckdb"
 )
